# File Converter

CSV to JSON and JSON to CSV converter.

## Introduction

Learning how to deploy a lib on PyPi at PUC using Poetry.

### What this project can do

Read a **csv** file or a **folder** and convert them to **JSON** and vice versa.
This project is a program running on terminal, preferably install with pipx:

```bash
pipx install luana_santos_csv_converter
```

To use, just type in:

```bash
csv_converter --help
```

Or:

```bash
json_converter --help
```